@@ -22,20 +22,15 @@
  */
 
 #ifndef lint
-static const char rcsid[] =
-    "@(#) $Header: /tcpdump/master/tcpdump/print-ah.c,v 1.14 2000/12/12 09:58:40 itojun Exp $ (LBL)";
+static const char rcsid[] _U_ =
+    "@(#) $Header: /tcpdump/master/tcpdump/print-ah.c,v 1.22 2003/11/19 00:36:06 guy Exp $ (LBL)";
 #endif
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include <sys/param.h>
-#include <sys/time.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-
-#include <netinet/in.h>
+#include <tcpdump-stdinc.h>
 
 #include <stdio.h>
 
@@ -43,34 +38,34 @@ static const char rcsid[] =
 
 #include "interface.h"
 #include "addrtoname.h"
+#include "extract.h"
 
 int
-ah_print(register const u_char *bp, register const u_char *bp2)
+ah_print(register const u_char *bp)
 {
 	register const struct ah *ah;
 	register const u_char *ep;
 	int sumlen;
 	u_int32_t spi;
 
-	ah = (struct ah *)bp;
+	ah = (const struct ah *)bp;
 	ep = snapend;		/* 'ep' points to the end of available data. */
 
-	if ((u_char *)(ah + 1) >= ep - sizeof(struct ah))
-		goto trunc;
+	TCHECK(*ah);
 
 	sumlen = ah->ah_len << 2;
-	spi = (u_int32_t)ntohl(ah->ah_spi);
+	spi = EXTRACT_32BITS(&ah->ah_spi);
 
 	printf("AH(spi=0x%08x", spi);
 	if (vflag)
 		printf(",sumlen=%d", sumlen);
-	printf(",seq=0x%x", (u_int32_t)ntohl(*(u_int32_t *)(ah + 1)));
+	printf(",seq=0x%x", EXTRACT_32BITS(ah + 1));
 	if (bp + sizeof(struct ah) + sumlen > ep)
 		fputs("[truncated]", stdout);
 	fputs("): ", stdout);
-	
+
 	return sizeof(struct ah) + sumlen;
  trunc:
 	fputs("[|AH]", stdout);
-	return 65535;
+	return -1;
 }
