@@ -26,7 +26,7 @@
 
 #ifndef lint
 static const char rcsid[] _U_ =
-    "@(#) $Header: /tcpdump/master/tcpdump/print-cdp.c,v 1.19.2.5 2004/03/24 06:00:51 guy Exp $";
+    "@(#) $Header: /tcpdump/master/tcpdump/print-cdp.c,v 1.25 2004/10/07 14:53:11 hannes Exp $";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -41,6 +41,7 @@ static const char rcsid[] _U_ =
 #include "interface.h"
 #include "addrtoname.h"
 #include "extract.h"			/* must come after interface.h */
+#include "nlpid.h"
 
 #define CDP_HEADER_LEN  4
 
@@ -260,7 +261,7 @@ cdp_print_addr(const u_char * p, int l)
 			goto trunc;
 		al = EXTRACT_16BITS(&p[pl]);	/* address length */
 
-		if (pt == PT_NLPID && pl == 1 && *p == 0xcc && al == 4) {
+		if (pt == PT_NLPID && pl == 1 && *p == NLPID_IP && al == 4) {
 			/*
 			 * IPv4: protocol type = NLPID, protocol length = 1
 			 * (1-byte NLPID), protocol = 0xcc (NLPID for IPv4),
